@@ -3,7 +3,7 @@ package Crypt::PRNG::RC4;
 use strict;
 use warnings;
 
-use Exporter 'import';
+use base qw(Crypt::PRNG Exporter);
 our %EXPORT_TAGS = ( all => [qw(random_bytes random_bytes_hex random_bytes_b64 random_bytes_b64u random_string random_string_from rand irand)] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
@@ -111,7 +111,7 @@ See L<Crypt::PRNG/irand>.
 
 =head1 METHODS
 
-=head1 new
+=head2 new
 
 See L<Crypt::PRNG/new>.
 
